@@ -19,6 +19,20 @@ function get_syslinux_version {
     echo "$syslinux_version"
 }
 
+function find_syslinux_file {
+    # input argument is usually isolinux.bin
+    # output argument is the full path of isolinux.bin
+    local syslinux_file=""
+
+    for file in /usr/{share,lib,libexec}/*/"$1" ; do
+        if [[ -s "$file" ]]; then
+            syslinux_file="$file"
+            break # for loop
+        fi
+    done
+    echo "$syslinux_file"
+}
+
 function set_syslinux_features {
 	# Test for features in syslinux
 	# true if isolinux supports booting from /boot/syslinux, /boot or only from / of the ISO
@@ -43,15 +57,15 @@ function set_syslinux_features {
 	FEATURE_SYSLINUX_MENU_HIDDEN=
 	# true if syslinux supports TEXT HELP directive
 	FEATURE_SYSLINUX_TEXT_HELP=
+        # true if syslinux supports modules sub-dir (Version > 5.00)
+        FEATURE_SYSLINUX_MODULES=
 
 	# Define the syslinux directory for later usage
 	if [[ -z "$SYSLINUX_DIR" ]]; then
-		for file in /usr/{share,lib,libexec}/*/isolinux.bin ; do
-			if [[ -s "$file" ]]; then
-				SYSLINUX_DIR="$(dirname $file)"
-				break # for loop
-			fi
-		done
+		ISOLINUX_BIN=$(find_syslinux_file isolinux.bin)
+		if [[ -s "$ISOLINUX_BIN" ]]; then
+			SYSLINUX_DIR="$(dirname $ISOLINUX_BIN)"
+		fi
 	fi
 	[[ "$SYSLINUX_DIR" ]]
 	StopIfError "Could not find a working syslinux path."
@@ -90,6 +104,10 @@ function set_syslinux_features {
 		FEATURE_SYSLINUX_EXTLINUX_INSTALL="y"
 	fi
 
+	if version_newer "$syslinux_version" 5.00; then
+		FEATURE_SYSLINUX_MODULES=y
+	fi
+
 	if [[ "$FEATURE_SYSLINUX_BOOT_SYSLINUX" ]]; then
 		SYSLINUX_PREFIX="boot/syslinux"
 	else
@@ -110,13 +128,25 @@ function make_syslinux_config {
 	[[ -d "$1" ]]
 	BugIfError "Required argument for BOOT_DIR is missing"
 	[[ -d "$SYSLINUX_DIR" ]]
-	BugIfError "Required environment SYSLINUX_DIR ($SYSLINUX_DIR) is not set or not a d irectory"
+	BugIfError "Required environment SYSLINUX_DIR ($SYSLINUX_DIR) is not set or not a directory"
 	[[ "$FEATURE_SYSLINUX_IS_SET" ]]
 	BugIfError "You must call set_syslinux_features before"
 
 	local BOOT_DIR="$1" ; shift
 	local flavour="${1:-isolinux}" ; shift
 
+	if [[ "$FEATURE_SYSLINUX_MODULES" ]]; then
+		SYSLINUX_MODULES_DIR=
+		if [[ -d /usr/lib/syslinux/modules ]]; then
+			if (( USING_UEFI_BOOTLOADER )); then
+				SYSLINUX_MODULES_DIR=/usr/lib/syslinux/modules/efi64
+			else
+				SYSLINUX_MODULES_DIR=/usr/lib/syslinux/modules/bios
+			fi
+			SYSLINUX_DIR="$SYSLINUX_MODULES_DIR"
+		fi
+	fi
+
     # Enable serial console, unless explicitly disabled (only last entry is used :-/)
     if [[ "$USE_SERIAL_CONSOLE" =~ ^[yY1] ]]; then
         for devnode in $(ls /dev/ttyS[0-9]* | sort); do
